import babel from '@rollup/plugin-babel';
import terser from '@rollup/plugin-terser';
import copy from 'rollup-plugin-copy';

const versionIframe = '0.0.4';
const versionAddressSearchWidget = '1.0.1';

const iframeFileName = "kelvin-map-iframe";
const addressSearchWidgetFileName = "kelvin-address-search-widget";

export default [
  // Configuration for kelvin-map-iframe
  {
    input: `src/${iframeFileName}/index.js`,
    output: {
      file: `dist/${iframeFileName}-v${versionIframe}.min.js`,
      format: 'iife',
      sourcemap: true,
    },
    plugins: [
      babel({
        babelHelpers: 'bundled',
        presets: [
          [
            '@babel/preset-env',
            {
              targets: '> 0.25%, not dead',
              useBuiltIns: 'usage',
              corejs: 3,
            },
          ],
        ],
        exclude: 'node_modules/**', // Optional: Exclude node_modules if needed
      }),
      terser(),
      copy({
        targets: [
          {
            src: `dist/${iframeFileName}-v${versionIframe}.min.js`,
            dest: 'dist',
            rename: `${iframeFileName}-latest.min.js`,
          },
        ],
      }),
    ],
  },

  // Configuration for kelvin-address-search-widget
  {
    input: `src/${addressSearchWidgetFileName}/index.js`,
    output: {
      file: `dist/${addressSearchWidgetFileName}-v${versionAddressSearchWidget}.min.js`,
      format: 'iife',
      name: 'kelvinAddressSearchWidget',
      sourcemap: true,
    },
    plugins: [
      babel({
        babelHelpers: 'bundled',
        presets: [
          [
            '@babel/preset-env',
            {
              targets: '> 0.25%, not dead',
              useBuiltIns: 'usage',
              corejs: 3,
            },
          ],
        ],
        exclude: 'node_modules/**',
      }),
      terser(),
      copy({
        targets: [
          {
            src: `dist/${addressSearchWidgetFileName}-v${versionAddressSearchWidget}.min.js`,
            dest: 'dist',
            rename: `${addressSearchWidgetFileName}-latest.min.js`,
          },
        ],
      }),
    ],
  },
];
